import BlockInputs from './BlockInputs'
import { TextInput } from '../../form'
import { TBlockInstance } from '../types'
import theme from '../../styles/theme'

const BlockInstanceInputs = ({
  value,
  name,
  onChange,
  className,
}: {
  value: TBlockInstance
  name: string
  onChange: GenericEventHandler
  className?: string
}) => {
  return (
    <div className={className}>
      {!value.id.startsWith('++') && (
        <div className='bi-info'>
          <div>Block Instance ID{value.id}</div>
          <div>Created at: {value}</div>
        </div>
      )}
      <TextInput
        name={`${name}.order`}
        label='Order'
        value={value.order}
        type='number'
        onChange={onChange}
        className='bi-order'
      />
      <TextInput
        name={`${name}.rounds`}
        label='Rounds'
        value={value.rounds}
        type='number'
        onChange={onChange}
        className='bi-rounds'
      />
      <TextInput
        name={`${name}.variation`}
        label='Variation'
        value={value.variation}
        onChange={onChange}
        className='bi-variation'
      />
      <BlockInputs
        name={`${name}.block`}
        value={value.block}
        onChange={onChange}
        className='bi-block'
      />

      <style jsx>{`
        @media (min-width: ${theme.midsize}) {
          div {
            display: grid;
            grid-template-areas:
              'order  rounds variation'
              'block  block  block'
              'button button button';
            grid-template-columns: 1fr 1fr 2fr;
          }

          div :global(.bi-order) {
            grid-area: order;
          }
          div :global(.bi-rounds) {
            grid-area: rounds;
          }
          div :global(.bi-variation) {
            grid-area: variation;
          }
          div :global(.bi-block) {
            grid-area: block;
          }
          div :global(.bi-button) {
            grid-area: button;
          }
        }
      `}</style>
    </div>
  )
}

export default BlockInstanceInputs
